@@ -1,3 +1,5 @@
+testthat::skip_if_not_installed("ggplot2")
+
 card1 <- ReportCard$new()
 card1$append_text("Header 2 text", "header2")
 card1$append_text("A paragraph of default text", "header2")
@@ -30,6 +32,7 @@ testthat::test_that("download_report_button_srv - render and downlaod a document
       files <- list.files(output_dir, recursive = TRUE)
       testthat::expect_true(any(grepl("[.]Rmd", files)))
       testthat::expect_true(any(grepl("[.]html", files)))
+      testthat::expect_true(any(grepl("Report[.]json", files)))
       unlink(output_dir, recursive = TRUE)
     }
   )
@@ -129,6 +132,7 @@ testthat::test_that("report_render_and_compress - render an html document", {
   files <- list.files(temp_dir, recursive = TRUE)
   testthat::expect_true(any(grepl("[.]Rmd", files)))
   testthat::expect_true(any(grepl("[.]html", files)))
+  testthat::expect_true(any(grepl("Report[.]json", files)))
 })
 
 testthat::test_that("any_rcode_block", {
