@@ -1,5 +1,5 @@
 testthat::test_that("NewpageBlock object can be created", {
-  testthat::expect_error(NewpageBlock$new(), regexp = NA)
+  testthat::expect_no_error(NewpageBlock$new())
 })
 
 testthat::test_that("new returns an object of type NewpageBlock", {
@@ -8,5 +8,5 @@ testthat::test_that("new returns an object of type NewpageBlock", {
 
 testthat::test_that("set_content accepts a string", {
   block <- NewpageBlock$new()
-  testthat::expect_error(block$get_content(), regexp = NA)
+  testthat::expect_no_error(block$get_content())
 })
