@@ -14,14 +14,14 @@ card1 <- card_fun()
 reporter <- Reporter$new()
 reporter$append_cards(list(card1))
 
-testthat::test_that("simple_reporter_srv - reset a reporter", {
+testthat::test_that("reset_report_button_srv - reset a reporter", {
   shiny::testServer(
-    simple_reporter_srv,
-    args = list(reporter = reporter, card_fun = card_fun),
+    reset_report_button_srv,
+    args = list(reporter = reporter),
     expr = {
-      testthat::expect_identical(reporter$get_cards(), list(card1))
-      session$setInputs(`reset_button_simple-reset_reporter` = 0)
-      session$setInputs(`reset_button_simple-reset_reporter_ok` = 0)
+      testthat::expect_identical(unname(reporter$get_cards()), list(card1))
+      session$setInputs(`reset_reporter` = 0)
+      session$setInputs(`reset_reporter_ok` = 0)
       testthat::expect_identical(reporter$get_blocks(), list())
     }
   )
