@@ -8,7 +8,11 @@ testthat::test_that("new returns an object of type TableBlock", {
 
 testthat::test_that("set_content accepts a table object", {
   block <- TableBlock$new()
-  testthat::expect_no_error(block$set_content(iris))
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    testthat::expect_no_error(block$set_content(iris))
+  )
 })
 
 testthat::test_that("set_content asserts the argument is a plot", {
@@ -18,7 +22,11 @@ testthat::test_that("set_content asserts the argument is a plot", {
 
 testthat::test_that("set_content returns the TableBlock object", {
   block <- TableBlock$new()
-  testthat::expect_identical(block$set_content(iris), block)
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    testthat::expect_identical(block$set_content(iris), block)
+  )
 })
 
 testthat::test_that("get_content returns character(0) on a newly initialized TableBlock", {
@@ -28,19 +36,31 @@ testthat::test_that("get_content returns character(0) on a newly initialized Tab
 temp_dir <- tempdir()
 
 testthat::test_that("to_list returns a named list with a one field, a proper file name", {
-  block <- TableBlock$new()$set_content(iris)
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    block <- TableBlock$new()$set_content(iris)
+  )
   testthat::expect_equal(block$to_list(temp_dir), list(basename = basename(block$get_content())))
 })
 
 # to_list
 testthat::test_that("to_list returns a named list with a one field, a proper path", {
-  tblock <- TableBlock$new()$set_content(iris)
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    tblock <- TableBlock$new()$set_content(iris)
+  )
   testthat::expect_identical(tblock$to_list(temp_dir), list(basename = basename(tblock$get_content())))
 })
 
 # from_list
 testthat::test_that("from_list after to_list to save and retrive", {
-  tblock <- TableBlock$new()$set_content(iris)
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    tblock <- TableBlock$new()$set_content(iris)
+  )
   testthat::expect_identical(
     file.size(TableBlock$new()$from_list(
       tblock$to_list(temp_dir),
@@ -52,7 +72,11 @@ testthat::test_that("from_list after to_list to save and retrive", {
 
 testthat::test_that("set_content supports data.frame object", {
   block <- TableBlock$new()
-  testthat::expect_no_error(block$set_content(iris))
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    testthat::expect_no_error(block$set_content(iris))
+  )
 })
 
 testthat::test_that("set_content supports rtables object", {
@@ -65,5 +89,9 @@ testthat::test_that("set_content supports rtables object", {
         "range" = diff(range(x))
       )
     })
-  testthat::expect_no_error(block$set_content(rtables::build_table(l, iris)))
+  # https://github.com/davidgohel/flextable/issues/600
+  withr::with_options(
+    opts_partial_match_old,
+    testthat::expect_no_error(block$set_content(rtables::build_table(l, iris)))
+  )
 })
